@@ -3,11 +3,21 @@ from pyArango.collection import *
 from pyArango.graph import *
 from .support import *
 import datetime
-import params
+import os
+import json
 import re
 
 class BasicElement():
-    db_client = Connection(arangoURL=params.local_adb_url, username=params.local_adb_username, password=params.local_adb_password, verify=True, verbose=True, statsdClient=None, reportFileName=None, loadBalancing='round-robin', use_grequests=False, use_jwt_authentication=False, use_lock_for_reseting_jwt=True, max_retries=10)
+    if os.environ.get('D20_ORM_CONF') != None:
+        conf = json.loads(os.environ.get('D20_ORM_CONF'))
+        arangoURL=conf.get('D20_ORM_DBURL')
+        username=conf.get('D20_ORM_DBUSERNAME')
+        password=conf.get('D20_ORM_DBPASSWORD')        
+    else:
+        print("No configuration given, cannot start.")
+        raise Exception
+
+    db_client = Connection(arangoURL=arangoURL, username=username, password=password, verify=True, verbose=True, statsdClient=None, reportFileName=None, loadBalancing='round-robin', use_grequests=False, use_jwt_authentication=False, use_lock_for_reseting_jwt=True, max_retries=10)
     db_name = ''
     cascade = False
     @classmethod
@@ -112,13 +122,14 @@ class BasicElement():
             self._key = None
             self.status = False
 
-    def findGraph(self, query):
+    def findGraph(self, query, avoid_regex=False):
         search_query = []
         for k in query:
-            if isinstance(query[k], str):
+            if isinstance(query[k], str) and not avoid_regex:
                 # if type(query[k]) is not unicode:
                 #     query[k] = unicode(query[k], encoding='utf-8')
 
+                # query[k] = re.sub("+", '\+', query[k])
                 query[k] = re.sub("[àáâãäå]", 'a', query[k])
                 query[k] = re.sub("[èéêë]", 'e', query[k])
                 query[k] = re.sub("[ìíîï]", 'i', query[k])
@@ -134,7 +145,8 @@ class BasicElement():
     def search(self, query, limit=None):
         try:
         # qf = ' and '.join([ f'Regex_Test(m.`{att["dim"]}`,"{att["val"]}", true)' if isinstance(att['val'], str) else f'm.`{att["dim"]}` == {att["val"]}' for att in query])
-            qf = ' and '.join([ f'Regex_Test(m.`{att["dim"]}`,"{att["val"]}", true)' if isinstance(att['val'], str) else f'm.`{att["dim"]}` {att["op"]} {att["val"]}' for att in query])
+            # qf = ' and '.join([ f'Regex_Test(m.`{att["dim"]}`,"{att["val"]}", true)' if isinstance(att['val'], str) else f'm.`{att["dim"]}` {att["op"]} {att["val"]}' for att in query])
+            qf = ' and '.join([ f'm.`{att["dim"]}` {att["op"]} "{att["val"]}"' if isinstance(att['val'], str) else f'm.`{att["dim"]}` {att["op"]} {att["val"]}' for att in query])
             if limit != None:
                 qf = qf + ' limit ' + str(limit)
             query = 'for m in '+ self.get_collection() +'\
@@ -242,6 +254,8 @@ class BasicElement():
             self.find()
         elif mode == 'fetch':  # OK
             self.findGraph(data)
+        elif mode == 'fetch_exact':  # OK
+            self.findGraph(data, avoid_regex=True)
         elif mode == 'delete': # OK
             self.delete()
         elif mode == 'publish': # OK
